@@ -1,5 +1,4 @@
-import glob
-import os.path
+import pathlib
 import subprocess
 import sys
 
@@ -7,9 +6,13 @@ import pytest
 
 from vulture import core
 
-DIR = os.path.dirname(os.path.abspath(__file__))
-REPO = os.path.dirname(DIR)
-WHITELISTS = glob.glob(os.path.join(REPO, "vulture", "whitelists", "*.py"))
+REPO = pathlib.Path(__file__).resolve().parents[1]
+WHITELISTS = [
+    str(path)
+    for path in (REPO / "vulture" / "whitelists").glob("*.py")
+    # Pint is incompatible with Python 3.13 (https://github.com/hgrecco/pint/issues/1969).
+    if sys.version_info < (3, 13) or path.name != "pint_whitelist.py"
+]
 
 
 def call_vulture(args, **kwargs):
